=== modified file 'bzrlib/commit_signature_commands.py'
--- bzrlib/commit_signature_commands.py	2011-06-23 11:34:56 +0000
+++ bzrlib/commit_signature_commands.py	2011-06-23 12:08:21 +0000
@@ -123,13 +123,9 @@
         gpg_strategy = gpg.GPGStrategy(branch_config)
 
         gpg_strategy.set_acceptable_keys(acceptable_keys)
-        count = {gpg.SIGNATURE_VALID: 0,
-                 gpg.SIGNATURE_KEY_MISSING: 0,
-                 gpg.SIGNATURE_NOT_VALID: 0,
-                 gpg.SIGNATURE_NOT_SIGNED: 0}
-        result = []
+
+        #get our list of revisions
         revisions = []
-
         if revision is not None:
             if len(revision) == 1:
                 revno, rev_id = revision[0].in_history(branch)
@@ -158,15 +154,9 @@
                     continue
                 revisions.append(rev_id)
             repo.unlock()
-        for rev_id in revisions:
-            verification_result, uid = repo.verify_revision(rev_id,gpg_strategy)
-            result.append([rev_id, verification_result, uid])
-            count[verification_result] += 1
-
-        if count[gpg.SIGNATURE_VALID] > 0 and \
-           count[gpg.SIGNATURE_KEY_MISSING] == 0 and \
-           count[gpg.SIGNATURE_NOT_VALID] == 0 and \
-           count[gpg.SIGNATURE_NOT_SIGNED] == 0:
+        count, result, all_verifiable =\
+                                gpg_strategy.do_verifications(revisions, repo)
+        if all_verifiable:
                self.outf.write(gettext(
                             "All commits signed with verifiable keys\n"))
                if verbose:

=== modified file 'bzrlib/gpg.py'
--- bzrlib/gpg.py	2011-06-23 11:34:56 +0000
+++ bzrlib/gpg.py	2011-06-23 12:08:21 +0000
@@ -89,6 +89,22 @@
                 else:
                     self.acceptable_keys.append(pattern)
 
+    def do_verifications(self, revisions, repository):
+        count = {SIGNATURE_VALID: 0,
+                 SIGNATURE_KEY_MISSING: 0,
+                 SIGNATURE_NOT_VALID: 0,
+                 SIGNATURE_NOT_SIGNED: 0}
+        result = []
+        all_verifiable = True
+        for rev_id in revisions:
+            verification_result, uid =\
+                                repository.verify_revision(rev_id,self)
+            result.append([rev_id, verification_result, uid])
+            count[verification_result] += 1
+            if verification_result != SIGNATURE_VALID:
+                all_verifiable = False
+        return (count, result, all_verifiable)
+            
 
 def _set_gpg_tty():
     tty = os.environ.get('TTY')
@@ -244,3 +260,28 @@
                     trace.note(i18n.gettext(
                             "No GnuPG key results for pattern: {}"
                                 ).format(pattern))
+
+    def do_verifications(self, revisions, repository):
+        """do verifications on a set of revisions
+        
+        :param revisions: list of revision ids to verify
+        :param repository: repository object
+        
+        :return: count dictionary of results of each type,
+                 result list for each revision,
+                 boolean True if all results are verified successfully
+        """
+        count = {SIGNATURE_VALID: 0,
+                 SIGNATURE_KEY_MISSING: 0,
+                 SIGNATURE_NOT_VALID: 0,
+                 SIGNATURE_NOT_SIGNED: 0}
+        result = []
+        all_verifiable = True
+        for rev_id in revisions:
+            verification_result, uid =\
+                                repository.verify_revision(rev_id,self)
+            result.append([rev_id, verification_result, uid])
+            count[verification_result] += 1
+            if verification_result != SIGNATURE_VALID:
+                all_verifiable = False
+        return (count, result, all_verifiable)

